//
//  SIDFacebook.h
//  SocialID
//
//  Created by Renato Neves on 4/16/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "SIDSignIn.h"
#import "SIDUser.h"

@interface SIDFacebook : NSObject

/**
 Checks the current FBSession status.
 */
+ (void) initializeFacebook;

/**
 Handles the user leaving the app while the Facebook login dialog is being shown.
 For example: when the user presses the iOS "home" button while the login dialog is active.
 */
+ (void) handleDidBecomeActive;

/**
 During the Facebook login flow, your app passes control to the Facebook iOS app or Facebook in a mobile browser.
 After authentication, your app will be called back with the session information.
 */
+ (BOOL) handleOpenURL:(NSURL *)url
     sourceApplication:(NSString *)sourceApplication;

/**
 Performs the Social Login using the native Facebook login flow, returning the generated SIDSignIn or error.
 @param permissions The permissions to be asked to the user.
 @param success The callback in case of success. A SIDSignIn object is provided including the social login user id.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) logInWithPermissions:(NSArray *)permissions
                      success:(void (^)(SIDSignIn *signIn))success
                      failure:(void (^)(NSError *error))failure;

/**
 Performs the Social Login using the native Facebook login flow, returning the generated SIDUser or error.
 @param permissions The permissions to be asked to the user.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) logInWithPermissions:(NSArray *)permissions
                       fields:(NSString *)fields
                      success:(void (^)(SIDUser *user))success
                      failure:(void (^)(NSError *error))failure;

/**
 Performs the Facebook native login flow, returning the generated access token or error.
 @param permissions The permissions to be asked to the user.
 @param success The callback in case of success. A NSString object is provided with the user access token.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) logInFacebook:(NSArray *)permissions
               success:(void (^)(NSString *accessToken))success
               failure:(void (^)(NSError *error))failure;

/**
 Create a SIDSignIn object given a Facebook access token.
 @param accessToken A Facebook access token.
 @param success The callback in case of success. A SIDSignIn object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) createSignInFromAccessToken:(NSString *)accessToken
                             success:(void (^)(SIDSignIn *signIn))success
                             failure:(void (^)(NSError *error))failure;

/**
 Retrieves information specified by fields for the user associated with a SIDSignIn object.
 @param signIn The social login SignIn object.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) getUserFromSignIn:(SIDSignIn *)signIn
                    fields:(NSString *)fields
                   success:(void (^)(SIDUser *user))success
                   failure:(void (^)(NSError *error))failure;

/**
 Returns the current FBSession access token.
 @return The access token.
 */
+ (NSString *) accessToken;

@end
