//
//  SIDFacebook.h
//  SocialID
//
//  Created by Renato Neves on 4/16/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <GooglePlus/GooglePlus.h>
#import "SIDSignIn.h"
#import "SIDUser.h"

@interface SIDGoogle : NSObject

@property (copy, nonatomic) void (^success)(SIDSignIn *signIn);
@property (copy, nonatomic) void (^failure)(NSError *error);

/**
 Checks the current SignIn status.
 */
+ (void) initializeGoogle;
+ (SIDGoogle *)getInstance;

/**
 Performs the Google login flow, returning the generated access token or error.
 @param success The callback in case of success. A NSString object is provided with the user access token.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) logInGoogle:(void (^)(SIDSignIn *signIn))success
               failure:(void (^)(NSError *error))failure;

/**
 Create a SIDSignIn object given a Google access token.
 @param accessToken A Google access token.
 @param success The callback in case of success. A SIDSignIn object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) createSignInFromAccessToken:(NSString *)accessToken
                             success:(void (^)(SIDSignIn *signIn))success
                             failure:(void (^)(NSError *error))failure;

/**
 Retrieves information specified by fields for the user associated with a SIDSignIn object.
 @param signIn The social login SignIn object.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) getUserFromSignIn:(SIDSignIn *)signIn
                    fields:(NSString *)fields
                   success:(void (^)(SIDUser *user))success
                   failure:(void (^)(NSError *error))failure;

/**
 Google delegate methods
 */
+ (void) finishedWithAuth: (GTMOAuth2Authentication *)auth
                    error: (NSError *) error;
+ (BOOL) application: (UIApplication *)application
             openURL: (NSURL *)url
   sourceApplication: (NSString *)sourceApplication
          annotation: (id)annotation;
+ (void) setDelegate: (id)delegate;
@end
