//
//  SIDLinkedin.h
//  SocialID
//
//  Created by Dirceu Pereira Tiegs on 23/10/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "SIDSignIn.h"
#import "SIDUser.h"

@interface SIDLinkedin : NSObject <UIWebViewDelegate>

@property NSString *callbackUrl;
@property NSString *consumerKey;
@property NSString *consumerSecret;
@property NSString *token;
@property NSString *tokenSecret;
@property NSString *oauthVerifier;
@property UIWebView *webView;
@property (copy, nonatomic) void (^success)(SIDSignIn *signIn);
@property (copy, nonatomic) void (^failure)(NSError *error);

/**
 Checks the current SignIn status.
 */
+ (void) initializeLinkedin;

+ (SIDLinkedin *)getInstance;

/**
 Performs the login flow, returning the generated access token or error.
 @param success The callback in case of success. A NSString object is provided with the user access token.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) logInLinkedin:(void (^)(SIDSignIn *signIn))success
               failure:(void (^)(NSError *error))failure;

/**
 Create a SIDSignIn object given a Linkedin access token.
 @param accessToken A Linkedin access token.
 @param success The callback in case of success. A SIDSignIn object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) createSignInFromAccessToken:(NSString *)accessToken
                              secret:(NSString *)accessToken
                             success:(void (^)(SIDSignIn *signIn))success
                             failure:(void (^)(NSError *error))failure;

/**
 Retrieves information specified by fields for the user associated with a SIDSignIn object.
 @param signIn The social login SignIn object.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
+ (void) getUserFromSignIn:(SIDSignIn *)signIn
                    fields:(NSString *)fields
                   success:(void (^)(SIDUser *user))success
                   failure:(void (^)(NSError *error))failure;

@end
