//
//  SIDWiFi.h
//  SocialID
//
//  Created by Renato Neves on 7/24/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "SIDWiFiController.h"

@interface SIDWiFi : NSObject

@property NSObject<SIDWiFiController> *controller;

/**
 Initialize the object with given WiFi controller.
 @param controller
 */
- (instancetype) initWithController:(NSObject<SIDWiFiController> *)controller;

/**
 Checks if the WiFi Internet connectivity is available
 @param success A block object to be executed when the check completed successfully. It returns the WiFi status as "connected", if it's possible to browse pages, or "disconnected", if the pages are redirecting to a Captive Portal for authorization. The response object contains the raw response for the reference url page queried.
 @param failure A block object to be executed when the check failed. It could be triggered if the client doesn't have Internet connectivity.
 */
- (void) checkWiFiConnectionStatus:(void (^)(NSString *status, NSURLResponse* response))success
                           failure:(void (^)(NSError *error))failure;

/**
 Authorizes the token in the Wi-Fi controller.
 @param token The login token to send as a password to the controller.
 @param success A block object to be executed when the Wi-Fi authorization completed successfully. It is triggered only if the client was not connected to the Wi-Fi network before.
 @param failure A block object to be executed when the Wi-Fi authorization failed. It is triggered when it's not possible to post a request to the controller or if the controller returns an authentication failed response.
 */
- (void) authorize:(NSString *)token
           success:(void (^)())success
           failure:(void (^)(NSError *error))failure;

/**
 Authorizes the token in the Wi-Fi controller only if the given SSID is currently connected.
 @param token The login token to send as a password to the controller.
 @param SSID The Wi-Fi network SSID that should be currently connected.
 @param success A block object to be executed when the Wi-Fi authorization completed successfully. It is triggered only if the client was not connected to the Wi-Fi network before.
 @param failure A block object to be executed when the Wi-Fi authorization failed. It is triggered when it's not possible to post a request to the controller or if the controller returns an authentication failed response.
 */
- (void) authorize:(NSString *)token
           forSSID:(NSString *)SSID
           success:(void (^)())success
           failure:(void (^)(NSError *error))failure;

/**
 Returns the current Wi-Fi SSID.
 */
- (NSString *) currentWiFiSSID;

@end
