//
//  SocialID.h
//  SocialID
//
//  Created by Renato Neves on 2/3/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "SIDObject.h"
#import "SIDDevice.h"
#import "SIDPush.h"
#import "SIDFacebook.h"
#import "SIDGoogle.h"
#import "SIDLinkedin.h"

#import "SIDUser.h"
#import "SIDSignIn.h"
#import "SIDUserProfile.h"

// SDK Version
#define SID_VERSION_STRING @"1.0.1"

@interface SocialID : NSObject

@property NSInteger userId;

/**
 Returns a singleton instance of this class
 */
+ (SocialID *)getInstance;

/**
 Gets the current user and executes success() or failure()
 */
- (void) getUser:(NSString *)fields
         success:(void (^)(SIDUser *user))success
         failure:(void (^)(NSError *error))failure;

/**
 Log out by cleaning the session fields
 */
- (void) logout;

/**
 Sets the Social Login application id and secret.
 @param applicationId The Social Login application id.
 @param secret The Social Login application secret.
 */
+ (void) setApplicationId:(NSInteger)applicationId
                   secret:(NSString *)secret;

/**
 Sets the Marketing Account id and secret.
 @param applicationId The Marketing Account id.
 @param secret The Marketing Account secret.
 */
+ (void) setMarketingAccountId:(NSInteger)accountId
                        secret:(NSString *)secret;

/**
 Returns the Social Login application id.
 */
+ (NSInteger) getApplicationId;

/**
 Returns the Social Login application secret.
 */
+ (NSString *) getApplicationSecret;

/**
 Returns the Marketing Account id.
 */
+ (NSInteger) getMarketingAccountId;

/**
 Returns the Marketing Account secret.
 */
+ (NSString *) getMarketingAccountSecret;

@end